@@ -15,6 +15,7 @@ from lost_ds.functional.api import(remove_empty,
                                    to_abs,
                                    to_rel,
                                    transform_bbox_style,
+                                   to_coco,
                                    unique_labels,
                                    validate_empty_images,
                                    validate_geometries,
@@ -24,7 +25,8 @@ from lost_ds.functional.api import(remove_empty,
 
 from lost_ds.cropping.api import (DSCropper,
                                   crop_anno,
-                                  crop_dataset)
+                                  crop_dataset,
+                                  crop_components)
 
 from lost_ds.copy import (copy_imgs,
                           pack_ds)
@@ -34,18 +36,21 @@ from lost_ds.im_util import (get_imagesize,
 
 from lost_ds.vis.api import (vis_sample,
                              vis_and_store,
+                             vis_semantic_segmentation,
                              draw_polygons,
                              draw_boxes,
                              draw_lines,
-                             draw_points)
+                             draw_points,
+                             draw_text)
 
-from lost_ds.segmentation.api import (semantic_segmentation)
+from lost_ds.segmentation.api import (semantic_segmentation, 
+                                      segmentation_to_lost)
 
-from lost_ds.detection.api import (detection_dataset)
+from lost_ds.detection.api import (detection_dataset, bbox_nms)
 
 from lost_ds.util import (get_fs, 
                           to_parquet)
 
 from lost_ds.core import LOSTDataset
 
-__version__='0.0.0'
+__version__='0.2.0'
